/*
 *  Copyright 2021 Collate
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *  http://www.apache.org/licenses/LICENSE-2.0
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.openmetadata.service.secrets.converter;

import java.util.List;
import org.openmetadata.schema.services.connections.search.ElasticSearchConnection;
import org.openmetadata.schema.services.connections.search.elasticSearch.ESAPIAuth;
import org.openmetadata.schema.services.connections.search.elasticSearch.ESBasicAuth;
import org.openmetadata.service.util.JsonUtils;

/** Converter class to get an `ElasticSearchConnection` object. */
public class ElasticSearchConnectionClassConverter extends ClassConverter {

  private static final List<Class<?>> CONFIG_SOURCE_CLASSES =
      List.of(ESBasicAuth.class, ESAPIAuth.class);

  //
  public ElasticSearchConnectionClassConverter() {
    super(ElasticSearchConnection.class);
  }

  @Override
  public Object convert(Object object) {
    ElasticSearchConnection elasticSearchConnection =
        (ElasticSearchConnection) JsonUtils.convertValue(object, this.clazz);

    tryToConvert(elasticSearchConnection.getAuthType(), CONFIG_SOURCE_CLASSES)
        .ifPresent(elasticSearchConnection::setAuthType);

    return elasticSearchConnection;
  }
}
